package com.hungraim.ltc.system.controller;

import com.hungraim.ltc.system.config.FileUploadConfig;
import com.hungraim.ltc.system.service.AttachService;
import com.hungraim.ltc.util.FileUtils;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

@RestController
@RequestMapping("/api.system/resource")
@Slf4j
public class FileUploadController {

    @Autowired
    private FileUploadConfig fileUploadConfig;

    @Autowired
    private AttachService attachService;

    /**
     * 上传文件接口
     *
     * @param file       上传的文件
     * @param uploadType 附件类型 附件类型(1:失能人员附件;2:鉴定任务附件;3:服务方案附件;4:稽核巡查;5:护理机构基金结算申请新增;6:无锡长护保险自评申请;7:失能信息变更附件;
     *                   8:评估结论书;9:参保人员及家属;10:评定人员1;11:评定人员2;12:鉴定机构附件;13:护理机构附件;14:鉴定人员附件;15:护理人员附件 16-护理人员服务项目结束附件，17:建床，18：撤床)
     * @return 返回保存到数据库之后的文件id
     */
    @PostMapping("/uploadFile")
    public Result uploadFile(MultipartFile file, Short uploadType) {
        if (null == uploadType || null == file) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        String originalFilename = file.getOriginalFilename();
        String realPath = FileUtils.uploadFile(file, fileUploadConfig.getPath());
        log.info("文件上传成功:{}", realPath);
        Long attachId = attachService.saveFileInfo(originalFilename, realPath, uploadType);
        log.info("保存成功，文件id:{}", attachId);
        return Result.success(attachId);
    }
}
